Converting a set of branching times to a phylogeny
brts2phylo(times, root = FALSE, tip.label = NULL)Set of branching times
When root is FALSE, the largest branching time will be assumed to be the crown age. When root is TRUE, it will be the stem age.
Tip labels. If set to NULL, the labels will be t1, t2, etc.
A phylogeny of the phylo type
- Etienne, R.S. et al. 2012, Proc. Roy. Soc. B 279: 1300-1309, doi: 10.1098/rspb.2011.1439 - Etienne, R.S. & B. Haegeman 2012. Am. Nat. 180: E75-E89, doi: 10.1086/667574