simplex: Carries out optimization using a simplex algorithm (finding a minimum)
Description
Function to optimize target function using a
simplex method adopted from Matlab
Usage
simplex(fun, trparsopt, optimpars, ...)
Arguments
trparsopt
Initial guess of the parameters to be optimized
optimpars
Parameters of the optimization: relative tolerance in
function arguments, relative tolerance in function value, absolute tolerance
in function arguments, and maximum number of iterations
...
Any other arguments of the function to be optimimzed, or settings
of the optimization routine
Value
outA list containing optimal function arguments
(par, the optimal function value (fvalues) and whether the
optimization converged (conv)
.
Examples
Run this code# NOT RUN {
cat("No examples")
# }
Run the code above in your browser using DataLab